/**
 * Export all implementation classes, and convenience methods for each
 * @module
 */
import { FormatOptions } from './format.js';
import { SameOptions } from './same.js';
/**
 * The return value from all comparison functions.
 */
export interface Result {
    /**
     * Diff of formatted test object and expected pattern. Only shows
     * properties which differ, not the entire object.
     */
    diff: string;
    /**
     * whether or not the objects are a satisfying match
     */
    match: boolean;
}
/**
 * Options that can be used to set how diffs are formatted.
 */
export type CompareOptions = FormatOptions & Pick<SameOptions, 'diffContext'>;
/** format a value and return the formatted string */
export declare const format: (obj: any, options?: FormatOptions) => string;
/** convenience method for {@link tcompare!same.Same} */
export declare const same: (obj: any, pattern: any, options?: CompareOptions) => Result;
/** convenience method for {@link Strict} */
export declare const strict: (obj: any, pattern: any, options?: CompareOptions) => Result;
/** convenience method for {@link Has} */
export declare const has: (obj: any, pattern: any, options?: CompareOptions) => Result;
/** convenience method for {@link HasStrict} */
export declare const hasStrict: (obj: any, pattern: any, options?: CompareOptions) => Result;
/** convenience method for {@link Match} */
export declare const match: (obj: any, pattern: any, options?: CompareOptions) => Result;
/** convenience method for {@link MatchOnly} */
export declare const matchOnly: (obj: any, pattern: any, options?: CompareOptions) => Result;
/** convenience method for {@link MatchStrict} */
export declare const matchStrict: (obj: any, pattern: any, options?: CompareOptions) => Result;
/** convenience method for {@link MatchOnlyStrict} */
export declare const matchOnlyStrict: (obj: any, pattern: any, options?: CompareOptions) => Result;
export { Format } from './format.js';
export type { FormatOptions } from './format.js';
export { HasStrict } from './has-strict.js';
export { Has } from './has.js';
export { MatchOnly } from './match-only.js';
export { MatchStrict } from './match-strict.js';
export { MatchOnlyStrict } from './match-only-strict.js';
export { Match } from './match.js';
export { Same } from './same.js';
export type { SameOptions } from './same.js';
export { Strict } from './strict.js';
export { styles } from './styles.js';
export type { Style } from './styles.js';
//# sourceMappingURL=index.d.ts.map